@@ -23,12 +23,14 @@ declare(strict_types=1);
  * https://www.gnu.org/copyleft/gpl.html.
  */
 
-namespace ShapeFileTest;
+namespace PhpMyAdminTest\ShapeFile;
 
 use PhpMyAdmin\ShapeFile\ShapeFile;
 use PhpMyAdmin\ShapeFile\ShapeRecord;
 use PHPUnit\Framework\TestCase;
+
 use function count;
+use function method_exists;
 
 class ShapeFileTest extends TestCase
 {
@@ -59,7 +61,7 @@ class ShapeFileTest extends TestCase
      *
      * @return array
      */
-    public function provideFiles(): array
+    public static function provideFiles(): array
     {
         return [
             [
@@ -121,6 +123,7 @@ class ShapeFileTest extends TestCase
 
             return;
         }
+
         $this->assertEquals('Not a SHP file (file code mismatch)', $shp->lastError);
     }
 
@@ -138,7 +141,7 @@ class ShapeFileTest extends TestCase
      *
      * @return array
      */
-    public function provideErrorFiles(): array
+    public static function provideErrorFiles(): array
     {
         $result = [
             ['data/no-shp.*'],
@@ -287,7 +290,12 @@ class ShapeFileTest extends TestCase
     {
         $shp = new ShapeFile(1);
         $shp->saveToFile('./data/test_nodbf.*');
-        $this->assertFileNotExists('./data/test_nodbf.dbf');
+
+        if (method_exists($this, 'assertFileDoesNotExist')) {
+            $this->assertFileDoesNotExist('./data/test_nodbf.dbf');
+        } else {
+            $this->assertFileNotExists('./data/test_nodbf.dbf');
+        }
     }
 
     /**
@@ -360,10 +368,7 @@ class ShapeFileTest extends TestCase
                 continue;
             }
 
-            $this->assertEquals(
-                $record->shpData[$item],
-                $record2->shpData[$item]
-            );
+            $this->assertEquals($record->shpData[$item], $record2->shpData[$item]);
         }
 
         /* Test deletion works */
@@ -401,7 +406,7 @@ class ShapeFileTest extends TestCase
      *
      * @return array
      */
-    public function shapes(): array
+    public static function shapes(): array
     {
         return [
             [
